summaryrefslogtreecommitdiff
path: root/include/osl/file.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'include/osl/file.hxx')
-rw-r--r--include/osl/file.hxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/osl/file.hxx b/include/osl/file.hxx
index a53e3d77555f..a797da0e6c3f 100644
--- a/include/osl/file.hxx
+++ b/include/osl/file.hxx
@@ -170,7 +170,7 @@ public:
return static_cast< RC >( osl_getAbsoluteFileURL( ustrBaseDirectoryURL.pData, ustrRelativeFileURL.pData, &ustrAbsoluteFileURL.pData ) );
}
/** Convert a file URL into a system dependend path.
@param ustrFileURL [in]
A File URL.
@@ -190,7 +190,7 @@ public:
return static_cast< RC >( osl_getSystemPathFromFileURL( ustrFileURL.pData, &ustrSystemPath.pData ) );
}
/** Convert a system dependend path into a file URL.
@param ustrSystemPath [in]
A System dependent path of a file or directory.
@@ -217,7 +217,7 @@ public:
@param ustrSearchPath [in]
A list of system paths, in which a given file has to be searched. The Notation of a path list is
- system dependend, e.g. on UNIX system "/usr/bin:/bin" and on Windows "C:\BIN;C:\BATCH".
+ system dependent, e.g. on UNIX system "/usr/bin:/bin" and on Windows "C:\BIN;C:\BATCH".
These paths are only for the search of a file or a relative path, otherwise it will be ignored.
If ustrSearchPath is NULL or while using the search path the search failed, the function searches for
a matching file in all system directories and in the directories listed in the PATH environment
@@ -170,7 +170,7 @@ public:
return static_cast< RC >( osl_getAbsoluteFileURL( ustrBaseDirectoryURL.pData, ustrRelativeFileURL.pData, &ustrAbsoluteFileURL.pData ) );
}
- /** Convert a file URL into a system dependend path.
+ /** Convert a file URL into a system dependent path.
A File URL.
@@ -190,7 +190,7 @@ public:
return static_cast< RC >( osl_getSystemPathFromFileURL( ustrFileURL.pData, &ustrSystemPath.pData ) );
}
- /** Convert a system dependend path into a file URL.
+ /** Convert a system dependent path into a file URL.
A System dependent path of a file or directory.